==> mui-extension-4.2.0.tgz: package/lib/Toast/Toast.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { useContext, useState } from 'react';
import { Box, CircularProgress, Icon, IconButton, Snackbar } from '@mui/material';
import { colorInfo, colorSuccess, colorWarning } from '../_core/style/color';
var noop = function (_) { };
var ToastContext = React.createContext({
    toastError: noop,
    toastSuccess: noop,
    toastWarning: noop,
    toastInfo: noop,
    toastLoading: noop,
});
export var ToastProvider = function (_a) {
    var children = _a.children, _b = _a.vertical, vertical = _b === void 0 ? 'bottom' : _b, _c = _a.horizontal, horizontal = _c === void 0 ? 'left' : _c;
    var _d = useState(undefined), type = _d[0], setType = _d[1];
    var _e = useState(undefined), message = _e[0], setMessage = _e[1];
    var _f = useState(false), open = _f[0], setOpen = _f[1];
    var _g = useState(), options = _g[0], setOptions = _g[1];
    var pop = function (type) { return function (message, options) {
        setOpen(true);
        setType(type);
        setMessage(message);
        setOptions(options);
    }; };
    var renderIcon = function (type) {
        switch (type) {
            case 'error':
                return React.createElement(Icon, { sx: { color: function (t) { return t.palette.error.main; }, } }, "error");
            case 'success':
                return React.createElement(Icon, { sx: { color: colorSuccess, } }, "check_circle");
            case 'warning':
                return React.createElement(Icon, { sx: { color: colorWarning, } }, "warning");
            case 'info':
                return React.createElement(Icon, { sx: { color: colorInfo, } }, "info");
            case 'loading':
                return React.createElement(CircularProgress, { size: 24, thickness: 5 });
            default:
                return React.createElement(React.Fragment, null);
        }
    };
    var handleClose = function (event, reason) {
        var _a;
        if (reason === 'clickaway' && (options === null || options === void 0 ? void 0 : options.keepOpenOnClickAway)) {
        }
        else {
            setOpen(false);
        }
        (_a = options === null || options === void 0 ? void 0 : options.onClose) === null || _a === void 0 ? void 0 : _a.call(options, event);
    };
    return (React.createElement(ToastContext.Provider, { value: {
            toastError: pop('error'),
            toastSuccess: pop('success'),
            toastWarning: pop('warning'),
            toastInfo: pop('info'),
            toastLoading: pop('loading'),
        } },
        children,
        React.createElement(Snackbar, { anchorOrigin: { vertical: vertical, horizontal: horizontal }, open: open, autoHideDuration: (options === null || options === void 0 ? void 0 : options.autoHideDuration) === undefined ? type === 'error' ? null : 6000 : options.autoHideDuration, onClose: handleClose, message: React.createElement("div", { style: { display: 'flex', alignItems: 'center' } },
                renderIcon(type),
                React.createElement(Box, { component: "span", sx: { ml: 2 } }, message)), action: React.createElement(React.Fragment, null, options === null || options === void 0 ? void 0 :
                options.action,
                React.createElement(IconButton, { onClick: handleClose, color: "inherit", size: "large", sx: (options === null || options === void 0 ? void 0 : options.action) ? { ml: 1 } : {} },
                    React.createElement(Icon, null, "close"))) })));
};
export var useToast = function () { return useContext(ToastContext); };
export var withToast = function (Component) { return function (props) { return (React.createElement(ToastContext.Consumer, null, function (other) { return React.createElement(Component, __assign({}, props, other)); })); }; };

==> mui-extension-4.3.1.tgz: package/lib/Toast/Toast.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { useContext, useState } from 'react';
import { Box, CircularProgress, Icon, IconButton, Snackbar } from '@mui/material';
import { colorInfo, colorSuccess, colorWarning } from '../_core/style/color';
var ToastContext = React.createContext({});
export var ToastProvider = function (_a) {
    var children = _a.children, _b = _a.vertical, vertical = _b === void 0 ? 'bottom' : _b, _c = _a.horizontal, horizontal = _c === void 0 ? 'left' : _c;
    var _d = useState(false), open = _d[0], setOpen = _d[1];
    var _e = useState(undefined), type = _e[0], setType = _e[1];
    var _f = useState(undefined), message = _f[0], setMessage = _f[1];
    var _g = useState(), options = _g[0], setOptions = _g[1];
    var pop = function (type) { return function (message, options) {
        setOpen(true);
        setType(type);
        setMessage(message);
        setOptions(options);
        return { setOpen: setOpen, setType: setType, setMessage: setMessage, setOptions: setOptions, };
    }; };
    var renderIcon = function (type) {
        switch (type) {
            case 'error':
                return React.createElement(Icon, { sx: { color: function (t) { return t.palette.error.main; }, } }, "error");
            case 'success':
                return React.createElement(Icon, { sx: { color: colorSuccess, } }, "check_circle");
            case 'warning':
                return React.createElement(Icon, { sx: { color: colorWarning, } }, "warning");
            case 'info':
                return React.createElement(Icon, { sx: { color: colorInfo, } }, "info");
            case 'loading':
                return React.createElement(CircularProgress, { size: 24, thickness: 5 });
            default:
                return React.createElement(React.Fragment, null);
        }
    };
    var handleClose = function (event, reason) {
        var _a;
        if (reason === 'clickaway' && (options === null || options === void 0 ? void 0 : options.keepOpenOnClickAway)) {
        }
        else {
            setOpen(false);
        }
        (_a = options === null || options === void 0 ? void 0 : options.onClose) === null || _a === void 0 ? void 0 : _a.call(options, event);
    };
    return (React.createElement(ToastContext.Provider, { value: {
            toastError: pop('error'),
            toastSuccess: pop('success'),
            toastWarning: pop('warning'),
            toastInfo: pop('info'),
            toastLoading: pop('loading'),
        } },
        children,
        React.createElement(Snackbar, { anchorOrigin: { vertical: vertical, horizontal: horizontal }, open: open, autoHideDuration: (options === null || options === void 0 ? void 0 : options.autoHideDuration) === undefined ? type === 'error' ? null : 6000 : options.autoHideDuration, onClose: handleClose, message: React.createElement("div", { style: { display: 'flex', alignItems: 'center' } },
                renderIcon(type),
                React.createElement(Box, { component: "span", sx: { ml: 2 } }, message)), action: React.createElement(React.Fragment, null, options === null || options === void 0 ? void 0 :
                options.action,
                React.createElement(IconButton, { onClick: handleClose, color: "inherit", size: "large", sx: (options === null || options === void 0 ? void 0 : options.action) ? { ml: 1 } : {} },
                    React.createElement(Icon, null, "close"))) })));
};
export var useToast = function () { return useContext(ToastContext); };
export var withToast = function (Component) { return function (props) { return (React.createElement(ToastContext.Consumer, null, function (other) { return React.createElement(Component, __assign({}, props, other)); })); }; };
